Skip to contents

Returns default parameter values for disturbance scenarios. See simulateObservations() for additional details.

Usage

disturbanceDefaults(
  paramTable = NULL,
  iFire = 0,
  iAnthro = 0,
  obsAnthroSlope = 2,
  projAnthroSlope = 2,
  ...
)

Arguments

paramTable

a data.frame with column names matching the arguments below. Any columns that are missing will be filled with the default values.

iFire

number. Initial fire disturbance percentage.

iAnthro

number. Initial anthropogenic disturbance percentage

obsAnthroSlope

number. Percent change in anthropogenic disturbance per year in the observation period

projAnthroSlope

number. Percent change in anthropogenic disturbance per year in the projection period

Value

a data.frame of parameter values.

Examples

disturbanceDefaults()
#> # A tibble: 1 × 10
#>   iFire iAnthro obsAnthroSlope projAnthroSlope hasYear projYears obsYears
#>   <dbl>   <dbl>          <dbl>           <dbl> <lgl>       <dbl>    <dbl>
#> 1     0       0              2               2 FALSE          35       15
#> # ℹ 3 more variables: preYears <dbl>, curYear <dbl>, startYear <dbl>

# paramTable list takes precedence over argument values
disturbanceDefaults(paramTable = data.frame(iFire = 10, iAnthro = 20, obsYears = 1), obsYears = 5)
#>   iFire iAnthro obsAnthroSlope projAnthroSlope hasYear projYears obsYears
#> 1    10      20              2               2   FALSE        35        1
#>   preYears curYear startYear
#> 1        0    2023      2023