Skip to contents

Select the regression coefficient values and standard errors for the desired model version (see popGrowthTableJohnsonECCC for options) and then sample from the Gaussian distribution for each replicate population. getNationalCoefficients is a wrapper around subsetNationalCoefs(), which selects coefficients and sampleNationalCoefs(), which samples coefficients, for both the survival and recruitment models.

Usage

getNationalCoefficients(
  replicates,
  modelVersion = "Johnson",
  survivalModelNumber = "M1",
  recruitmentModelNumber = "M4",
  useQuantiles = TRUE,
  populationGrowthTable = popGrowthTableJohnsonECCC
)

sampleNationalCoefs(coefTable, replicates)

subsetNationalCoefs(populationGrowthTable, resVar, modelVersion, modNum)

Arguments

replicates

integer. Number of replicate populations.

modelVersion

character. Which model version to use. Currently the only option is "Johnson" for the model used in Johnson et. al. (2020), but additional options may be added in the future.

survivalModelNumber, recruitmentModelNumber

character. Which model number to use see popGrowthTableJohnsonECCC for options.

useQuantiles

logical or numeric. If it is a numeric vector it must be length 2 and give the low and high limits of the quantiles to use. If useQuantiles != FALSE, each replicate population is assigned to a quantile of the distribution of variation around the expected values, and remains in that quantile as covariates change. If useQuantiles = TRUE, replicate populations will be assigned to quantiles in the default range of 0.025 and 0.975.

populationGrowthTable

data.frame.popGrowthTableJohnsonECCC is included in the package and should be used in most cases. A custom table of model coefficients and standard errors or confidence intervals can be provided but it must match the column names of popGrowthTableJohnsonECCC. If the table does not contain the standard error it is calculated from the confidence interval.

coefTable

data.table. Table must have columns "Coefficient" for the name of the coefficient, "Value" for the value of the coefficient and "StdErr" for the standard error of coefficients. Typically created with subsetNationalCoefs()

resVar

character. Response variable, typically "femaleSurvival" or "recruitment"

modNum

character vector. Which model number(s) to use see popGrowthTableJohnsonECCC for typical options.

Value

For getNationalCoefficients a list with elements:

  • "modelVersion": The name of the model version

  • "coefSamples_Survival" and"coefSamples_Recruitment": lists with elements:

    • "coefSamples": Bootstrapped coefficients with replicates rows

    • "coefValues": Coefficient values taken from populationGrowthTable

    • "quantiles": A vector of randomly selected quantiles between 0.025 and 0.975 with length replicates

For sampleNationalCoefs a list with elements:

  • "coefSamples": Bootstrapped coefficients with replicates rows

  • "coefValues": Coefficient values taken from populationGrowthTable

For subsetNationalCoefs: a named list with one element per model version. The names are modelVersion_modNum_Type. Each element contains a data.frame that is a subset of populationGrowthTable for the selected model

Details

Each population is optionally assigned to quantiles of the error distributions for survival and recruitment. Using quantiles means that the population will stay in these quantiles as disturbance changes over time, so there is persistent variation in recruitment and survival among example populations. See estimateNationalRates() for more details.

References

Johnson, C.A., Sutherland, G.D., Neave, E., Leblond, M., Kirby, P., Superbie, C. and McLoughlin, P.D., 2020. Science to inform policy: linking population dynamics to habitat for a threatened species in Canada. Journal of Applied Ecology, 57(7), pp.1314-1327. https://doi.org/10.1111/1365-2664.13637

Examples

# sample coefficients for default models
getNationalCoefficients(10)
#> $modelVersion
#> [1] "Johnson"
#> 
#> $coefSamples_Survival
#> $coefSamples_Survival$coefSamples
#>        Intercept        Anthro Precision
#>  [1,] -0.1527585 -0.0006551097  89.69815
#>  [2,] -0.1437134 -0.0008425053  65.02295
#>  [3,] -0.1430621 -0.0009138259  63.44672
#>  [4,] -0.1400240 -0.0005052231  65.01437
#>  [5,] -0.1495847 -0.0008071118  59.18608
#>  [6,] -0.1302093 -0.0007767517  50.08337
#>  [7,] -0.1516406 -0.0006596685  72.03235
#>  [8,] -0.1513054 -0.0007524176  74.10782
#>  [9,] -0.1403526 -0.0008284290  55.97943
#> [10,] -0.1345159 -0.0005835474  49.28213
#> 
#> $coefSamples_Survival$coefValues
#>    Intercept Anthro Precision
#>        <num>  <num>     <num>
#> 1:    -0.142 -8e-04  63.43724
#> 
#> $coefSamples_Survival$coefStdErrs
#>      Intercept      Anthro Precision
#>          <num>       <num>     <num>
#> 1: 0.007908163 0.000127551  8.272731
#> 
#> $coefSamples_Survival$quantiles
#>  [1] 0.8694444 0.5527778 0.4472222 0.7638889 0.6583333 0.3416667 0.1305556
#>  [8] 0.9750000 0.2361111 0.0250000
#> 
#> 
#> $coefSamples_Recruitment
#> $coefSamples_Recruitment$coefSamples
#>        Intercept      Anthro Fire_excl_anthro Precision
#>  [1,] -1.0491279 -0.01896614     -0.008459309  17.65184
#>  [2,] -1.0997790 -0.01718310     -0.008489284  18.67540
#>  [3,] -1.0547924 -0.01614857     -0.009380439  22.51970
#>  [4,] -1.0354435 -0.01788571     -0.008817842  18.25898
#>  [5,] -1.0368057 -0.01520966     -0.009915698  23.02463
#>  [6,] -0.9456065 -0.01726778     -0.008371926  20.04628
#>  [7,] -1.0256320 -0.01866811     -0.011074601  16.33645
#>  [8,] -0.9557599 -0.01867291     -0.008561495  22.91236
#>  [9,] -1.0025937 -0.01950292     -0.010573639  16.69007
#> [10,] -1.0689690 -0.01543097     -0.010016498  22.46272
#> 
#> $coefSamples_Recruitment$coefValues
#>    Intercept Anthro Fire_excl_anthro Precision
#>        <num>  <num>            <num>     <num>
#> 1:    -1.023 -0.017          -0.0081  19.86189
#> 
#> $coefSamples_Recruitment$coefStdErrs
#>     Intercept      Anthro Fire_excl_anthro Precision
#>         <num>       <num>            <num>     <num>
#> 1: 0.06122449 0.001530612      0.002040816  2.228655
#> 
#> $coefSamples_Recruitment$quantiles
#>  [1] 0.0250000 0.3416667 0.5527778 0.2361111 0.6583333 0.8694444 0.9750000
#>  [8] 0.7638889 0.4472222 0.1305556
#> 
#> 

# try a different model
getNationalCoefficients(10, modelVersion = "Johnson", survivalModelNumber = "M1",
                        recruitmentModelNumber = "M3")
#> $modelVersion
#> [1] "Johnson"
#> 
#> $coefSamples_Survival
#> $coefSamples_Survival$coefSamples
#>        Intercept        Anthro Precision
#>  [1,] -0.1380693 -0.0007685582  60.22039
#>  [2,] -0.1268591 -0.0006768499  65.93089
#>  [3,] -0.1332614 -0.0006719284  48.98227
#>  [4,] -0.1465150 -0.0006866938  78.70447
#>  [5,] -0.1513312 -0.0007404478  71.09932
#>  [6,] -0.1321968 -0.0005883171  69.64860
#>  [7,] -0.1411494 -0.0006544076  58.06496
#>  [8,] -0.1405812 -0.0006713719  61.06160
#>  [9,] -0.1429145 -0.0007875770  61.00352
#> [10,] -0.1467512 -0.0006836891  62.12546
#> 
#> $coefSamples_Survival$coefValues
#>    Intercept Anthro Precision
#>        <num>  <num>     <num>
#> 1:    -0.142 -8e-04  63.43724
#> 
#> $coefSamples_Survival$coefStdErrs
#>      Intercept      Anthro Precision
#>          <num>       <num>     <num>
#> 1: 0.007908163 0.000127551  8.272731
#> 
#> $coefSamples_Survival$quantiles
#>  [1] 0.6583333 0.2361111 0.5527778 0.4472222 0.7638889 0.3416667 0.0250000
#>  [8] 0.8694444 0.1305556 0.9750000
#> 
#> 
#> $coefSamples_Recruitment
#> $coefSamples_Recruitment$coefSamples
#>        Intercept  Total_dist
#>  [1,] -0.9243167 -0.01243937
#>  [2,] -0.9379580 -0.01530224
#>  [3,] -0.8751008 -0.01375402
#>  [4,] -1.0985126 -0.01754605
#>  [5,] -1.0484420 -0.01658714
#>  [6,] -1.0726314 -0.01800168
#>  [7,] -1.0025335 -0.01254697
#>  [8,] -0.9879280 -0.01393954
#>  [9,] -0.9044461 -0.01760349
#> [10,] -0.9898251 -0.01452931
#> 
#> $coefSamples_Recruitment$coefValues
#>    Intercept Total_dist
#>        <num>      <num>
#> 1:    -0.956     -0.015
#> 
#> $coefSamples_Recruitment$coefStdErrs
#>    Intercept  Total_dist
#>        <num>       <num>
#> 1: 0.0619898 0.001530612
#> 
#> $coefSamples_Recruitment$quantiles
#>  [1] 0.5527778 0.9750000 0.4472222 0.1305556 0.7638889 0.0250000 0.8694444
#>  [8] 0.3416667 0.6583333 0.2361111
#> 
#> 

cfs <- subsetNationalCoefs(popGrowthTableJohnsonECCC, "recruitment", "Johnson", "M3")

sampleNationalCoefs(cfs[[1]], 10)
#> $coefSamples
#>        Intercept  Total_dist
#>  [1,] -1.0768888 -0.01372982
#>  [2,] -0.9486297 -0.01597337
#>  [3,] -0.8722177 -0.01517473
#>  [4,] -1.0006949 -0.01655965
#>  [5,] -1.0698436 -0.01868413
#>  [6,] -0.8563522 -0.01565316
#>  [7,] -0.8841886 -0.01423690
#>  [8,] -0.9352574 -0.01428082
#>  [9,] -0.9864658 -0.01419726
#> [10,] -0.9093856 -0.01482756
#> 
#> $coefValues
#>    Intercept Total_dist
#>        <num>      <num>
#> 1:    -0.956     -0.015
#> 
#> $coefStdErrs
#>    Intercept  Total_dist
#>        <num>       <num>
#> 1: 0.0619898 0.001530612
#> 

subsetNationalCoefs(popGrowthTableJohnsonECCC, "femaleSurvival", "Johnson", "M1")
#> $Johnson_M1_National
#>    modelVersion responseVariable ModelNumber     Type Coefficient    Value
#>          <char>           <char>      <char>   <char>      <char>    <num>
#> 1:      Johnson   femaleSurvival          M1 National   Intercept -0.14200
#> 2:      Johnson   femaleSurvival          M1 National      Anthro -0.00080
#> 3:      Johnson   femaleSurvival          M1 National   Precision 63.43724
#>         StdErr lowerCI upperCI
#>          <num>   <num>   <num>
#> 1: 0.007908163  -0.158 -0.1270
#> 2: 0.000127551  -0.001 -0.0005
#> 3: 8.272730950      NA      NA
#>