Skip to contents

Returns default parameter values for scenario durations. See simulateObservations() for additional details.

Usage

timeDefaults(
  paramTable = NULL,
  projYears = 35,
  obsYears = 15,
  preYears = 0,
  curYear = 2023,
  startYear = NA,
  ...
)

Arguments

paramTable

a data.frame with column names matching the arguments below. Any columns that are missing will be filled with the default values.

projYears

Number of years of projections

obsYears

Number of years of observations

preYears

Number of years before monitoring begins

curYear

year. The current year. All years before are part of the observation period and years after are part of the projection period.

startYear

year. First year in observation period. Optional, if not provided it will be calculated from curYear and obsYears

Value

a data.frame of parameter values.

Examples

timeDefaults()
#> # A tibble: 1 × 6
#>   hasYear projYears obsYears preYears curYear startYear
#>   <lgl>       <dbl>    <dbl>    <dbl>   <dbl>     <dbl>
#> 1 FALSE          35       15        0    2023      2009