Demographic projections for cases with no change in demographic rates over time. This is the method used (so far) in the demography app. TO DO: Consider removing and replacing with call to trajectoriesFromSummary.
Source:R/trajectoriesFromSummaryForApp.R
trajectoriesFromSummaryForApp.RdDemographic projections for cases with no change in demographic rates over time. This is the method used (so far) in the demography app. TO DO: Consider removing and replacing with call to trajectoriesFromSummary.
Usage
trajectoriesFromSummaryForApp(
numSteps,
replicates,
N0,
R_bar,
S_bar,
R_sd,
S_sd,
R_iv_mean,
R_iv_shape,
S_iv_mean,
S_iv_shape,
scn_nm,
type = "logistic",
addl_params = list(),
doSummary = F,
returnSamples = T
)Arguments
- numSteps
Number. Number of years to project.
- replicates
- N0
Number or vector of numbers. Initial population size for one or more sample populations. If NA then population growth rate is $_t=S_t*(1+cR_t)/s$.
- R_bar
Number or vector of numbers. Expected recruitment rate (calf:cow ratio) for one or more sample populations.
- S_bar
Number or vector of numbers. Expected adult female survival for one or more sample populations.
- R_sd, S_sd
standard deviation of R_bar and S_bar
- R_iv_mean, R_iv_shape, S_iv_mean, S_iv_shape
define the mean and shape of the interannual variation
- scn_nm
Scenario name
- type
"logistic" or "beta" defines how demographic rates are sampled from the given mean and standard deviation.
- addl_params
a list of additional parameters for
caribouPopGrowth- doSummary
logical. Default TRUE. If FALSE returns unprocessed outcomes from caribouPopGrowth. If TRUE returns summaries and (if returnSamples = T) sample trajectories from prepareTrajectories.
- returnSamples
logical. If FALSE returns only summaries. If TRUE returns example trajectories as well.
See also
Caribou demography functions:
bayesianScenariosWorkflow(),
bayesianTrajectoryWorkflow(),
betaNationalPriors(),
caribouPopGrowth(),
compareTrajectories(),
compositionBiasCorrection(),
convertTrajectories(),
dataFromSheets(),
demographicProjectionApp(),
estimateBayesianRates(),
estimateNationalRate(),
getNationalCoefficients(),
getScenarioDefaults(),
plotCompareTrajectories(),
plotSurvivalSeries(),
plotTrajectories(),
popGrowthTableJohnsonECCC,
simulateObservations(),
trajectoriesFromBayesian(),
trajectoriesFromNational(),
trajectoriesFromSummary()
Examples
outParTab <- trajectoriesFromSummaryForApp(
numSteps = 5, replicates = 2, N0 = NA, R_bar = 0.18, S_bar = 0.87,
R_sd = 0.085, S_sd = 0.16,
R_iv_mean = 0.34, S_iv_mean = 0.31,
R_iv_shape = 18, S_iv_shape = 3.3,
scn_nm = "base", addl_params = NULL, type = "logistic"
)
outParTab
#> N0 lambda lambdaE N R_t X_t S_t n_recruits
#> 1 NA 0.9483000 0.9483000 NA 0.18000000 0.09000000 0.8700000 NA
#> 2 NA 0.9483000 0.9483000 NA 0.18000000 0.09000000 0.8700000 NA
#> 3 NA 0.9483000 0.9483000 NA 0.18000000 0.09000000 0.8700000 NA
#> 4 NA 0.9483000 0.9483000 NA 0.18000000 0.09000000 0.8700000 NA
#> 5 NA 0.9483000 0.9483000 NA 0.18000000 0.09000000 0.8700000 NA
#> 6 NA 0.9627045 0.9435052 NA 0.26753134 0.13376567 0.8491212 NA
#> 7 NA 0.8275686 0.9195736 NA 0.18655902 0.09327951 0.7569597 NA
#> 8 NA 0.9340159 0.9435052 NA 0.09414307 0.04707154 0.8920268 NA
#> 9 NA 0.9931391 0.9195736 NA 0.11725163 0.05862581 0.9381399 NA
#> 10 NA 0.9163300 0.9435052 NA 0.13204096 0.06602048 0.8595801 NA
#> 11 NA 0.9052254 0.9195736 NA 0.12562279 0.06281140 0.8517272 NA
#> 12 NA 0.9298131 0.9435052 NA 0.14560451 0.07280226 0.8667143 NA
#> 13 NA 0.9378824 0.9195736 NA 0.17999233 0.08999617 0.8604456 NA
#> 14 NA 0.9604022 0.9435052 NA 0.23747384 0.11873692 0.8584701 NA
#> 15 NA 0.9681967 0.9195736 NA 0.26947730 0.13473865 0.8532332 NA
#> surviving_adFemales id time type scn
#> 1 NA 1 1 mean base
#> 2 NA 1 2 mean base
#> 3 NA 1 3 mean base
#> 4 NA 1 4 mean base
#> 5 NA 1 5 mean base
#> 6 NA 1 1 samp base
#> 7 NA 2 1 samp base
#> 8 NA 1 2 samp base
#> 9 NA 2 2 samp base
#> 10 NA 1 3 samp base
#> 11 NA 2 3 samp base
#> 12 NA 1 4 samp base
#> 13 NA 2 4 samp base
#> 14 NA 1 5 samp base
#> 15 NA 2 5 samp base