Calculate bias correction term for calf:cow composition survey.
Source:R/compositionBiasCorrection.R
compositionBiasCorrection.RdWhen composition surveys are conducted there is a possibility of bias in calf cow ratios due to misidentifying young bulls as adult females and vice versa or missing calves. Here we address this gap with a bias term derived from a simple model of the recruitment survey observation process. See Hughes et al. (2025) Section 2.2 for a detailed description of the model.
Arguments
- w
number. The apparent number of adult females per collared animal in composition survey.
- q
number in 0, 1. Ratio of bulls to cows in composition survey groups.
- u
number in 0, 1. Probability of misidentifying young bulls as adult females and vice versa in composition survey.
- z
number in 0, <1. Probability of missing calves in composition survey.
- approx
logical. If TRUE approximate the uncertainty about the value of the composition bias correction value (c) with the log-normal distribution of c given all the supplied values of
q,u, andz. If FALSE the composition bias correction value (c) is returned for each value ofq,u, andz
Value
number or tibble. If approx = FALSE a vector of composition bias
correction values (c) of the same length as q, u, and z. If approx = TRUE
a tibble with one row per unique value of w and columns w, m,
v, sig2, mu representing w, mean c, variance of c, and parameters for a
log-normal approximation of the distribution of c.
References
Hughes, J., Endicott, S., Calvert, A.M. and Johnson, C.A., 2025. Integration of national demographic-disturbance relationships and local data can improve caribou population viability projections and inform monitoring decisions. Ecological Informatics, 87, p.103095. https://doi.org/10.1016/j.ecoinf.2025.103095
See also
Caribou demography functions:
bayesianScenariosWorkflow(),
bayesianTrajectoryWorkflow(),
betaNationalPriors(),
caribouPopGrowth(),
compareTrajectories(),
convertTrajectories(),
dataFromSheets(),
demographicProjectionApp(),
estimateBayesianRates(),
estimateNationalRate(),
getNationalCoefficients(),
getScenarioDefaults(),
plotCompareTrajectories(),
plotSurvivalSeries(),
plotTrajectories(),
popGrowthTableJohnsonECCC,
simulateObservations(),
trajectoriesFromBayesian(),
trajectoriesFromNational(),
trajectoriesFromSummary(),
trajectoriesFromSummaryForApp()
Examples
# number of reps
nr <- 10
compositionBiasCorrection(w = 6,
q = runif(nr, 0, 0.6),
u = runif(nr, 0, 0.2),
z = runif(nr, 0, 0.2),
approx = FALSE)
#> [1] 1.1661548 1.0585390 0.9631785 1.0308220 1.0676801 1.1464445 1.1046932
#> [8] 1.1136361 1.0715216 1.0449723
compositionBiasCorrection(w = 6,
q = runif(nr, 0, 0.6),
u = runif(nr, 0, 0.2),
z = runif(nr, 0, 0.2),
approx = TRUE)
#> # A tibble: 1 × 5
#> w m v sig2 mu
#> <dbl> <dbl> <dbl> <dbl> <dbl>
#> 1 6 1.02 0.00377 0.00365 0.0136