Skip to contents

Select the regression coefficient values and standard errors for the desired model version (see popGrowthTableJohnsonECCC for options) and then sample from the Gaussian distribution for each replicate population. getNationalCoefficients is a wrapper around subsetNationalCoefs(), which selects coefficients and sampleNationalCoefs(), which samples coefficients, for both the survival and recruitment models.

Usage

getNationalCoefficients(
  replicates,
  modelVersion = "Johnson",
  survivalModelNumber = "M1",
  recruitmentModelNumber = "M4",
  useQuantiles = TRUE,
  populationGrowthTable = popGrowthTableJohnsonECCC
)

sampleNationalCoefs(coefTable, replicates)

subsetNationalCoefs(populationGrowthTable, resVar, modelVersion, modNum)

Arguments

replicates

integer. Number of replicate populations.

modelVersion

character. Which model version to use. Currently the only option is "Johnson" for the model used in Johnson et. al. (2020), but additional options may be added in the future.

survivalModelNumber, recruitmentModelNumber

character. Which model number to use see popGrowthTableJohnsonECCC for options.

useQuantiles

logical or numeric. If it is a numeric vector it must be length 2 and give the low and high limits of the quantiles to use. If useQuantiles != FALSE, each replicate population is assigned to a quantile of the distribution of variation around the expected values, and remains in that quantile as covariates change. If useQuantiles = TRUE, replicate populations will be assigned to quantiles in the default range of 0.025 and 0.975.

populationGrowthTable

data.frame.popGrowthTableJohnsonECCC is included in the package and should be used in most cases. A custom table of model coefficients and standard errors or confidence intervals can be provided but it must match the column names of popGrowthTableJohnsonECCC. If the table does not contain the standard error it is calculated from the confidence interval.

coefTable

data.table. Table must have columns "Coefficient" for the name of the coefficient, "Value" for the value of the coefficient and "StdErr" for the standard error of coefficients. Typically created with subsetNationalCoefs()

resVar

character. Response variable, typically "femaleSurvival" or "recruitment"

modNum

character vector. Which model number(s) to use see popGrowthTableJohnsonECCC for typical options.

Value

For getNationalCoefficients a list with elements:

  • "modelVersion": The name of the model version

  • "coefSamples_Survival" and"coefSamples_Recruitment": lists with elements:

    • "coefSamples": Bootstrapped coefficients with replicates rows

    • "coefValues": Coefficient values taken from populationGrowthTable

    • "quantiles": A vector of randomly selected quantiles between 0.025 and 0.975 with length replicates

For sampleNationalCoefs a list with elements:

  • "coefSamples": Bootstrapped coefficients with replicates rows

  • "coefValues": Coefficient values taken from populationGrowthTable

For subsetNationalCoefs: a named list with one element per model version. The names are modelVersion_modNum_Type. Each element contains a data.frame that is a subset of populationGrowthTable for the selected model

Details

Each population is optionally assigned to quantiles of the error distributions for survival and recruitment. Using quantiles means that the population will stay in these quantiles as disturbance changes over time, so there is persistent variation in recruitment and survival among example populations. See estimateNationalRates() for more details.

References

Johnson, C.A., Sutherland, G.D., Neave, E., Leblond, M., Kirby, P., Superbie, C. and McLoughlin, P.D., 2020. Science to inform policy: linking population dynamics to habitat for a threatened species in Canada. Journal of Applied Ecology, 57(7), pp.1314-1327. https://doi.org/10.1111/1365-2664.13637

Examples

# sample coefficients for default models
getNationalCoefficients(10)
#> $modelVersion
#> [1] "Johnson"
#> 
#> $coefSamples_Survival
#> $coefSamples_Survival$coefSamples
#>        Intercept        Anthro Precision
#>  [1,] -0.1389170 -0.0008324049  64.64004
#>  [2,] -0.1490448 -0.0008379345  67.12160
#>  [3,] -0.1415036 -0.0008461309  62.19260
#>  [4,] -0.1474598 -0.0009533913  58.59042
#>  [5,] -0.1415612 -0.0008892053  63.81832
#>  [6,] -0.1462586 -0.0007673662  69.12737
#>  [7,] -0.1351663 -0.0009883603  62.37509
#>  [8,] -0.1516367 -0.0007951413  56.96045
#>  [9,] -0.1380340 -0.0005976942  60.41268
#> [10,] -0.1382736 -0.0006537359  57.19652
#> 
#> $coefSamples_Survival$coefValues
#>    Intercept Anthro Precision
#>        <num>  <num>     <num>
#> 1:    -0.142 -8e-04  63.43724
#> 
#> $coefSamples_Survival$coefStdErrs
#>      Intercept      Anthro Precision
#>          <num>       <num>     <num>
#> 1: 0.007908163 0.000127551  8.272731
#> 
#> $coefSamples_Survival$quantiles
#>  [1] 0.6583333 0.5527778 0.0250000 0.9750000 0.3416667 0.7638889 0.1305556
#>  [8] 0.2361111 0.4472222 0.8694444
#> 
#> 
#> $coefSamples_Recruitment
#> $coefSamples_Recruitment$coefSamples
#>        Intercept      Anthro Fire_excl_anthro Precision
#>  [1,] -1.0387697 -0.01788934     -0.008932546  18.30847
#>  [2,] -1.0453700 -0.01595428     -0.007773468  19.93756
#>  [3,] -0.9592082 -0.01730525     -0.006467375  18.33757
#>  [4,] -1.1233987 -0.01684691     -0.010985729  18.91797
#>  [5,] -1.0420395 -0.01811414     -0.006596154  18.37059
#>  [6,] -1.0307975 -0.01571820     -0.008483132  16.93235
#>  [7,] -1.0229322 -0.01895534     -0.006859485  23.28813
#>  [8,] -0.9957401 -0.01850514     -0.004833767  23.78798
#>  [9,] -1.1259176 -0.01710310     -0.006438315  21.28264
#> [10,] -1.0580173 -0.01533625     -0.010397097  25.23927
#> 
#> $coefSamples_Recruitment$coefValues
#>    Intercept Anthro Fire_excl_anthro Precision
#>        <num>  <num>            <num>     <num>
#> 1:    -1.023 -0.017          -0.0081  19.86189
#> 
#> $coefSamples_Recruitment$coefStdErrs
#>     Intercept      Anthro Fire_excl_anthro Precision
#>         <num>       <num>            <num>     <num>
#> 1: 0.06122449 0.001530612      0.002040816  2.228655
#> 
#> $coefSamples_Recruitment$quantiles
#>  [1] 0.9750000 0.4472222 0.5527778 0.0250000 0.3416667 0.1305556 0.6583333
#>  [8] 0.8694444 0.2361111 0.7638889
#> 
#> 

# try a different model
getNationalCoefficients(10, modelVersion = "Johnson", survivalModelNumber = "M1",
                        recruitmentModelNumber = "M3")
#> $modelVersion
#> [1] "Johnson"
#> 
#> $coefSamples_Survival
#> $coefSamples_Survival$coefSamples
#>        Intercept        Anthro Precision
#>  [1,] -0.1438369 -0.0007286060  55.18041
#>  [2,] -0.1435678 -0.0007661048  52.67409
#>  [3,] -0.1440548 -0.0008000009  60.91883
#>  [4,] -0.1418438 -0.0004810170  67.93259
#>  [5,] -0.1325200 -0.0007115106  56.74545
#>  [6,] -0.1390084 -0.0006549467  57.38105
#>  [7,] -0.1532215 -0.0007568017  57.61061
#>  [8,] -0.1416163 -0.0009157795  69.41280
#>  [9,] -0.1510989 -0.0010865966  62.06624
#> [10,] -0.1483626 -0.0008982323  59.42729
#> 
#> $coefSamples_Survival$coefValues
#>    Intercept Anthro Precision
#>        <num>  <num>     <num>
#> 1:    -0.142 -8e-04  63.43724
#> 
#> $coefSamples_Survival$coefStdErrs
#>      Intercept      Anthro Precision
#>          <num>       <num>     <num>
#> 1: 0.007908163 0.000127551  8.272731
#> 
#> $coefSamples_Survival$quantiles
#>  [1] 0.1305556 0.4472222 0.5527778 0.9750000 0.8694444 0.2361111 0.7638889
#>  [8] 0.0250000 0.6583333 0.3416667
#> 
#> 
#> $coefSamples_Recruitment
#> $coefSamples_Recruitment$coefSamples
#>        Intercept  Total_dist
#>  [1,] -0.9043741 -0.01349656
#>  [2,] -0.9515655 -0.01498975
#>  [3,] -0.9722342 -0.01695382
#>  [4,] -1.0485387 -0.01603993
#>  [5,] -1.0733488 -0.01233485
#>  [6,] -0.9230422 -0.01417424
#>  [7,] -0.9720429 -0.01301088
#>  [8,] -0.9529556 -0.01617212
#>  [9,] -0.8692739 -0.01712575
#> [10,] -0.8982421 -0.01596018
#> 
#> $coefSamples_Recruitment$coefValues
#>    Intercept Total_dist
#>        <num>      <num>
#> 1:    -0.956     -0.015
#> 
#> $coefSamples_Recruitment$coefStdErrs
#>    Intercept  Total_dist
#>        <num>       <num>
#> 1: 0.0619898 0.001530612
#> 
#> $coefSamples_Recruitment$quantiles
#>  [1] 0.5527778 0.6583333 0.4472222 0.2361111 0.8694444 0.9750000 0.7638889
#>  [8] 0.3416667 0.1305556 0.0250000
#> 
#> 

cfs <- subsetNationalCoefs(popGrowthTableJohnsonECCC, "recruitment", "Johnson", "M3")

sampleNationalCoefs(cfs[[1]], 10)
#> $coefSamples
#>        Intercept  Total_dist
#>  [1,] -1.0231492 -0.01496860
#>  [2,] -0.9775411 -0.01383283
#>  [3,] -0.9509170 -0.01509112
#>  [4,] -0.9047475 -0.01622565
#>  [5,] -0.8714204 -0.01324880
#>  [6,] -0.9351984 -0.01596629
#>  [7,] -0.9640254 -0.01153559
#>  [8,] -0.9887548 -0.01677518
#>  [9,] -0.9839987 -0.01347968
#> [10,] -1.0207203 -0.01699075
#> 
#> $coefValues
#>    Intercept Total_dist
#>        <num>      <num>
#> 1:    -0.956     -0.015
#> 
#> $coefStdErrs
#>    Intercept  Total_dist
#>        <num>       <num>
#> 1: 0.0619898 0.001530612
#> 

subsetNationalCoefs(popGrowthTableJohnsonECCC, "femaleSurvival", "Johnson", "M1")
#> $Johnson_M1_National
#>    modelVersion responseVariable ModelNumber     Type Coefficient    Value
#>          <char>           <char>      <char>   <char>      <char>    <num>
#> 1:      Johnson   femaleSurvival          M1 National   Intercept -0.14200
#> 2:      Johnson   femaleSurvival          M1 National      Anthro -0.00080
#> 3:      Johnson   femaleSurvival          M1 National   Precision 63.43724
#>         StdErr lowerCI upperCI
#>          <num>   <num>   <num>
#> 1: 0.007908163  -0.158 -0.1270
#> 2: 0.000127551  -0.001 -0.0005
#> 3: 8.272730950      NA      NA
#>