Sample demographic regression model coefficients
Source:R/getNationalCoefficients.R, R/sampleNationalCoefs.R, R/subsetNationalCoefs.R
getNationalCoefficients.RdSelect the regression coefficient values and standard errors for the desired
model version (see popGrowthTableJohnsonECCC for options) and then sample
from the Gaussian distribution for each replicate population.
getNationalCoefficients is a wrapper around subsetNationalCoefs(), which selects
coefficients and sampleNationalCoefs(), which samples coefficients, for both the
survival and recruitment models.
Usage
getNationalCoefficients(
replicates,
modelVersion = "Johnson",
survivalModelNumber = "M1",
recruitmentModelNumber = "M4",
useQuantiles = TRUE,
populationGrowthTable = popGrowthTableJohnsonECCC
)
sampleNationalCoefs(coefTable, replicates)
subsetNationalCoefs(populationGrowthTable, resVar, modelVersion, modNum)Arguments
- replicates
integer. Number of replicate populations.
- modelVersion
character. Which model version to use. Currently the only option is "Johnson" for the model used in Johnson et. al. (2020), but additional options may be added in the future.
- survivalModelNumber, recruitmentModelNumber
character. Which model number to use see popGrowthTableJohnsonECCC for options.
- useQuantiles
logical or numeric. If it is a numeric vector it must be length 2 and give the low and high limits of the quantiles to use. If
useQuantiles != FALSE, each replicate population is assigned to a quantile of the distribution of variation around the expected values, and remains in that quantile as covariates change. IfuseQuantiles = TRUE, replicate populations will be assigned to quantiles in the default range of 0.025 and 0.975.- populationGrowthTable
data.frame.popGrowthTableJohnsonECCC is included in the package and should be used in most cases. A custom table of model coefficients and standard errors or confidence intervals can be provided but it must match the column names of popGrowthTableJohnsonECCC. If the table does not contain the standard error it is calculated from the confidence interval.
- coefTable
data.table. Table must have columns "Coefficient" for the name of the coefficient, "Value" for the value of the coefficient and "StdErr" for the standard error of coefficients. Typically created with
subsetNationalCoefs()- resVar
character. Response variable, typically "femaleSurvival" or "recruitment"
- modNum
character vector. Which model number(s) to use see popGrowthTableJohnsonECCC for typical options.
Value
For getNationalCoefficients a list with elements:
"modelVersion": The name of the model version
"coefSamples_Survival" and"coefSamples_Recruitment": lists with elements:
"coefSamples": Bootstrapped coefficients with
replicatesrows"coefValues": Coefficient values taken from
populationGrowthTable"quantiles": A vector of randomly selected quantiles between 0.025 and 0.975 with length
replicates
For sampleNationalCoefs a list with elements:
"coefSamples": Bootstrapped coefficients with
replicatesrows"coefValues": Coefficient values taken from
populationGrowthTable
For subsetNationalCoefs: a named list with one element per model version. The names are
modelVersion_modNum_Type. Each element contains a data.frame that is a subset
of populationGrowthTable for the selected model
Details
Each population is optionally assigned to quantiles of the error
distributions for survival and recruitment. Using quantiles means that the
population will stay in these quantiles as disturbance changes over time, so
there is persistent variation in recruitment and survival among example
populations. See estimateNationalRates() for more details.
References
Johnson, C.A., Sutherland, G.D., Neave, E., Leblond, M., Kirby, P., Superbie, C. and McLoughlin, P.D., 2020. Science to inform policy: linking population dynamics to habitat for a threatened species in Canada. Journal of Applied Ecology, 57(7), pp.1314-1327. https://doi.org/10.1111/1365-2664.13637
See also
Caribou demography functions:
bayesianScenariosWorkflow(),
bayesianTrajectoryWorkflow(),
betaNationalPriors(),
caribouPopGrowth(),
compareTrajectories(),
compositionBiasCorrection(),
convertTrajectories(),
dataFromSheets(),
demographicProjectionApp(),
estimateBayesianRates(),
estimateNationalRate(),
getScenarioDefaults(),
plotCompareTrajectories(),
plotSurvivalSeries(),
plotTrajectories(),
popGrowthTableJohnsonECCC,
simulateObservations(),
trajectoriesFromBayesian(),
trajectoriesFromNational(),
trajectoriesFromSummary(),
trajectoriesFromSummaryForApp()
Examples
# sample coefficients for default models
getNationalCoefficients(10)
#> $modelVersion
#> [1] "Johnson"
#>
#> $coefSamples_Survival
#> $coefSamples_Survival$coefSamples
#> Intercept Anthro Precision
#> [1,] -0.1454425 -0.0008586351 74.21946
#> [2,] -0.1496137 -0.0007478467 63.02003
#> [3,] -0.1435555 -0.0008424288 61.04753
#> [4,] -0.1361873 -0.0005876863 75.96500
#> [5,] -0.1400661 -0.0006636187 74.48095
#> [6,] -0.1400841 -0.0010481100 66.89606
#> [7,] -0.1547517 -0.0008189091 58.69334
#> [8,] -0.1352600 -0.0006477389 71.37043
#> [9,] -0.1360786 -0.0008322764 68.06164
#> [10,] -0.1339579 -0.0006169666 55.92882
#>
#> $coefSamples_Survival$coefValues
#> Intercept Anthro Precision
#> <num> <num> <num>
#> 1: -0.142 -8e-04 63.43724
#>
#> $coefSamples_Survival$coefStdErrs
#> Intercept Anthro Precision
#> <num> <num> <num>
#> 1: 0.007908163 0.000127551 8.272731
#>
#> $coefSamples_Survival$quantiles
#> [1] 0.6583333 0.9750000 0.5527778 0.2361111 0.8694444 0.0250000 0.1305556
#> [8] 0.3416667 0.7638889 0.4472222
#>
#>
#> $coefSamples_Recruitment
#> $coefSamples_Recruitment$coefSamples
#> Intercept Anthro Fire_excl_anthro Precision
#> [1,] -0.9719509 -0.01648627 -0.007865473 20.87759
#> [2,] -1.0463936 -0.01368228 -0.007991376 19.13202
#> [3,] -0.9664707 -0.01702704 -0.009688014 15.60922
#> [4,] -0.9388437 -0.01805089 -0.010070364 20.39234
#> [5,] -1.0486008 -0.01892992 -0.006438709 21.82140
#> [6,] -0.9700902 -0.01977882 -0.006975084 21.35387
#> [7,] -0.9637249 -0.01547470 -0.010832542 17.23006
#> [8,] -0.9716928 -0.01674265 -0.011420207 18.40731
#> [9,] -1.0385770 -0.01538642 -0.007708916 18.18876
#> [10,] -0.9945778 -0.01681727 -0.008620448 23.55904
#>
#> $coefSamples_Recruitment$coefValues
#> Intercept Anthro Fire_excl_anthro Precision
#> <num> <num> <num> <num>
#> 1: -1.023 -0.017 -0.0081 19.86189
#>
#> $coefSamples_Recruitment$coefStdErrs
#> Intercept Anthro Fire_excl_anthro Precision
#> <num> <num> <num> <num>
#> 1: 0.06122449 0.001530612 0.002040816 2.228655
#>
#> $coefSamples_Recruitment$quantiles
#> [1] 0.0250000 0.2361111 0.8694444 0.6583333 0.5527778 0.7638889 0.1305556
#> [8] 0.9750000 0.4472222 0.3416667
#>
#>
# try a different model
getNationalCoefficients(10, modelVersion = "Johnson", survivalModelNumber = "M1",
recruitmentModelNumber = "M3")
#> $modelVersion
#> [1] "Johnson"
#>
#> $coefSamples_Survival
#> $coefSamples_Survival$coefSamples
#> Intercept Anthro Precision
#> [1,] -0.1447466 -0.0008632489 73.36494
#> [2,] -0.1335798 -0.0007110085 53.95490
#> [3,] -0.1432310 -0.0009849595 52.63546
#> [4,] -0.1535674 -0.0007360112 57.27970
#> [5,] -0.1393579 -0.0008563992 60.96236
#> [6,] -0.1250249 -0.0008374968 65.16184
#> [7,] -0.1484290 -0.0007674773 54.01590
#> [8,] -0.1570609 -0.0008204144 70.72940
#> [9,] -0.1370469 -0.0007128045 65.06369
#> [10,] -0.1512367 -0.0009396197 63.47248
#>
#> $coefSamples_Survival$coefValues
#> Intercept Anthro Precision
#> <num> <num> <num>
#> 1: -0.142 -8e-04 63.43724
#>
#> $coefSamples_Survival$coefStdErrs
#> Intercept Anthro Precision
#> <num> <num> <num>
#> 1: 0.007908163 0.000127551 8.272731
#>
#> $coefSamples_Survival$quantiles
#> [1] 0.5527778 0.7638889 0.1305556 0.0250000 0.4472222 0.2361111 0.9750000
#> [8] 0.3416667 0.6583333 0.8694444
#>
#>
#> $coefSamples_Recruitment
#> $coefSamples_Recruitment$coefSamples
#> Intercept Total_dist
#> [1,] -0.8967587 -0.01622280
#> [2,] -0.9615260 -0.01510084
#> [3,] -1.0312674 -0.01476787
#> [4,] -1.0335653 -0.01498766
#> [5,] -0.9498751 -0.01394600
#> [6,] -0.9453266 -0.01688730
#> [7,] -0.9505345 -0.01160353
#> [8,] -0.8732372 -0.01673230
#> [9,] -0.9448173 -0.01269726
#> [10,] -1.0785601 -0.01778263
#>
#> $coefSamples_Recruitment$coefValues
#> Intercept Total_dist
#> <num> <num>
#> 1: -0.956 -0.015
#>
#> $coefSamples_Recruitment$coefStdErrs
#> Intercept Total_dist
#> <num> <num>
#> 1: 0.0619898 0.001530612
#>
#> $coefSamples_Recruitment$quantiles
#> [1] 0.0250000 0.4472222 0.6583333 0.5527778 0.2361111 0.1305556 0.8694444
#> [8] 0.3416667 0.9750000 0.7638889
#>
#>
cfs <- subsetNationalCoefs(popGrowthTableJohnsonECCC, "recruitment", "Johnson", "M3")
sampleNationalCoefs(cfs[[1]], 10)
#> $coefSamples
#> Intercept Total_dist
#> [1,] -1.0442864 -0.01819258
#> [2,] -0.9075438 -0.01366718
#> [3,] -1.0469545 -0.01304122
#> [4,] -1.0216237 -0.01497216
#> [5,] -1.0207756 -0.01477207
#> [6,] -0.8654777 -0.01775404
#> [7,] -0.9994064 -0.01534867
#> [8,] -0.9205988 -0.01288837
#> [9,] -0.9892358 -0.01759662
#> [10,] -0.8898193 -0.01419861
#>
#> $coefValues
#> Intercept Total_dist
#> <num> <num>
#> 1: -0.956 -0.015
#>
#> $coefStdErrs
#> Intercept Total_dist
#> <num> <num>
#> 1: 0.0619898 0.001530612
#>
subsetNationalCoefs(popGrowthTableJohnsonECCC, "femaleSurvival", "Johnson", "M1")
#> $Johnson_M1_National
#> modelVersion responseVariable ModelNumber Type Coefficient Value
#> <char> <char> <char> <char> <char> <num>
#> 1: Johnson femaleSurvival M1 National Intercept -0.14200
#> 2: Johnson femaleSurvival M1 National Anthro -0.00080
#> 3: Johnson femaleSurvival M1 National Precision 63.43724
#> StdErr lowerCI upperCI
#> <num> <num> <num>
#> 1: 0.007908163 -0.158 -0.1270
#> 2: 0.000127551 -0.001 -0.0005
#> 3: 8.272730950 NA NA
#>