Default parameters for specifying scenario durations.
Source:R/getScenarioDefaults.R
timeDefaults.RdReturns default parameter values for scenario durations.
See simulateObservations() for additional details.
Usage
timeDefaults(
paramTable = NULL,
projYears = 35,
obsYears = 15,
preYears = 0,
curYear = 2023,
startYear = NA,
...
)Arguments
- paramTable
a data.frame with column names matching the arguments below. Any columns that are missing will be filled with the default values.
- projYears
Number of years of projections
- obsYears
Number of years of observations
- preYears
Number of years before monitoring begins
- curYear
year. The current year. All years before are part of the observation period and years after are part of the projection period.
- startYear
year. First year in observation period. Optional, if not provided it will be calculated from
curYearandobsYears
See also
Caribou demography functions:
bayesianScenariosWorkflow(),
bayesianTrajectoryWorkflow(),
betaNationalPriors(),
caribouPopGrowth(),
compareTrajectories(),
compositionBiasCorrection(),
convertTrajectories(),
dataFromSheets(),
demographicProjectionApp(),
demographyDefaults(),
disturbanceDefaults(),
estimateBayesianRates(),
estimateNationalRate(),
getNationalCoefficients(),
getScenarioDefaults(),
monitoringDefaults(),
nationalTrajectoryDefaults(),
plotCompareTrajectories(),
plotSurvivalSeries(),
plotTrajectories(),
popGrowthTableJohnsonECCC,
simulateObservations(),
trajectoriesFromBayesian(),
trajectoriesFromNational(),
trajectoriesFromSummary(),
trajectoriesFromSummaryForApp()