Demographic projections for cases with no change in demographic rates over time. This is the method used (so far) in the demography app. TO DO: Consider removing and replacing with call to trajectoriesFromSummary.
Source:R/trajectoriesFromSummaryForApp.R
trajectoriesFromSummaryForApp.RdDemographic projections for cases with no change in demographic rates over time. This is the method used (so far) in the demography app. TO DO: Consider removing and replacing with call to trajectoriesFromSummary.
Usage
trajectoriesFromSummaryForApp(
numSteps,
replicates,
N0,
R_bar,
S_bar,
R_sd,
S_sd,
R_iv_mean,
R_iv_shape,
S_iv_mean,
S_iv_shape,
scn_nm,
type = "logistic",
addl_params = list(),
doSummary = F,
returnSamples = T
)Arguments
- numSteps
Number. Number of years to project.
- replicates
- N0
Number or vector of numbers. Initial population size for one or more sample populations. If NA then population growth rate is $_t=S_t*(1+cR_t)/s$.
- R_bar
Number or vector of numbers. Expected recruitment rate (calf:cow ratio) for one or more sample populations.
- S_bar
Number or vector of numbers. Expected adult female survival for one or more sample populations.
- R_sd, S_sd
standard deviation of R_bar and S_bar
- R_iv_mean, R_iv_shape, S_iv_mean, S_iv_shape
define the mean and shape of the interannual variation
- scn_nm
Scenario name
- type
"logistic" or "beta" defines how demographic rates are sampled from the given mean and standard deviation.
- addl_params
a list of additional parameters for
caribouPopGrowth- doSummary
logical. Default TRUE. If FALSE returns unprocessed outcomes from caribouPopGrowth. If TRUE returns summaries and (if returnSamples = T) sample trajectories from prepareTrajectories.
- returnSamples
logical. If FALSE returns only summaries. If TRUE returns example trajectories as well.
See also
Caribou demography functions:
bayesianScenariosWorkflow(),
bayesianTrajectoryWorkflow(),
betaNationalPriors(),
caribouPopGrowth(),
compareTrajectories(),
compositionBiasCorrection(),
convertTrajectories(),
dataFromSheets(),
demographicProjectionApp(),
estimateBayesianRates(),
estimateNationalRate(),
getNationalCoefficients(),
getScenarioDefaults(),
plotCompareTrajectories(),
plotSurvivalSeries(),
plotTrajectories(),
popGrowthTableJohnsonECCC,
simulateObservations(),
trajectoriesFromBayesian(),
trajectoriesFromNational(),
trajectoriesFromSummary()
Examples
outParTab <- trajectoriesFromSummaryForApp(
numSteps = 5, replicates = 2, N0 = NA, R_bar = 0.18, S_bar = 0.87,
R_sd = 0.085, S_sd = 0.16,
R_iv_mean = 0.34, S_iv_mean = 0.31,
R_iv_shape = 18, S_iv_shape = 3.3,
scn_nm = "base", addl_params = NULL, type = "logistic"
)
#> Error in trajectoriesFromSummaryForApp(numSteps = 5, replicates = 2, N0 = NA, R_bar = 0.18, S_bar = 0.87, R_sd = 0.085, S_sd = 0.16, R_iv_mean = 0.34, S_iv_mean = 0.31, R_iv_shape = 18, S_iv_shape = 3.3, scn_nm = "base", addl_params = NULL, type = "logistic"): N0 is not a numeric with length 1 or 2
outParTab
#> Error: object 'outParTab' not found