Skip to contents

Demographic projections for cases with no change in demographic rates over time. This is the method used (so far) in the demography app. TO DO: Consider removing and replacing with call to trajectoriesFromSummary.

Usage

trajectoriesFromSummaryForApp(
  numSteps,
  replicates,
  N0,
  R_bar,
  S_bar,
  R_sd,
  S_sd,
  R_iv_mean,
  R_iv_shape,
  S_iv_mean,
  S_iv_shape,
  scn_nm,
  type = "logistic",
  addl_params = list(),
  doSummary = F,
  returnSamples = T
)

Arguments

numSteps

Number. Number of years to project.

replicates
N0

Number or vector of numbers. Initial population size for one or more sample populations. If NA then population growth rate is $_t=S_t*(1+cR_t)/s$.

R_bar

Number or vector of numbers. Expected recruitment rate (calf:cow ratio) for one or more sample populations.

S_bar

Number or vector of numbers. Expected adult female survival for one or more sample populations.

R_sd, S_sd

standard deviation of R_bar and S_bar

R_iv_mean, R_iv_shape, S_iv_mean, S_iv_shape

define the mean and shape of the interannual variation

scn_nm

Scenario name

type

"logistic" or "beta" defines how demographic rates are sampled from the given mean and standard deviation.

addl_params

a list of additional parameters for caribouPopGrowth

doSummary

logical. Default TRUE. If FALSE returns unprocessed outcomes from caribouPopGrowth. If TRUE returns summaries and (if returnSamples = T) sample trajectories from prepareTrajectories.

returnSamples

logical. If FALSE returns only summaries. If TRUE returns example trajectories as well.

Value

a data.frame

Examples

 outParTab <- trajectoriesFromSummaryForApp(
   numSteps = 5, replicates = 2, N0 = NA, R_bar = 0.18, S_bar = 0.87,
   R_sd = 0.085, S_sd = 0.16,
   R_iv_mean = 0.34, S_iv_mean = 0.31,
   R_iv_shape = 18, S_iv_shape = 3.3,
   scn_nm = "base", addl_params = NULL, type = "logistic"
 )
 outParTab
#>    N0    lambda   lambdaE  N       R_t        X_t       S_t n_recruits
#> 1  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 2  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 3  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 4  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 5  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 6  NA 0.8905118 0.9444784 NA 0.1213325 0.06066623 0.8395778         NA
#> 7  NA 0.8740698 0.9243566 NA 0.2187095 0.10935473 0.7879083         NA
#> 8  NA 0.9712738 0.9444784 NA 0.2797872 0.13989360 0.8520741         NA
#> 9  NA 0.8638387 0.9243566 NA 0.1386525 0.06932626 0.8078345         NA
#> 10 NA 0.9206652 0.9444784 NA 0.1999912 0.09999561 0.8369717         NA
#> 11 NA 0.9678935 0.9243566 NA 0.2089757 0.10448784 0.8763279         NA
#> 12 NA 0.8633291 0.9444784 NA 0.1582588 0.07912938 0.8000237         NA
#> 13 NA 0.9061276 0.9243566 NA 0.1447513 0.07237567 0.8449722         NA
#> 14 NA 0.9844520 0.9444784 NA 0.2082642 0.10413210 0.8916071         NA
#> 15 NA 0.8883743 0.9243566 NA 0.1709812 0.08549058 0.8184081         NA
#>    surviving_adFemales id time type  scn
#> 1                   NA  1    1 mean base
#> 2                   NA  1    2 mean base
#> 3                   NA  1    3 mean base
#> 4                   NA  1    4 mean base
#> 5                   NA  1    5 mean base
#> 6                   NA  1    1 samp base
#> 7                   NA  2    1 samp base
#> 8                   NA  1    2 samp base
#> 9                   NA  2    2 samp base
#> 10                  NA  1    3 samp base
#> 11                  NA  2    3 samp base
#> 12                  NA  1    4 samp base
#> 13                  NA  2    4 samp base
#> 14                  NA  1    5 samp base
#> 15                  NA  2    5 samp base