Demographic projections for cases with no change in demographic rates over time. This is the method used (so far) in the demography app. TO DO: Consider removing and replacing with call to trajectoriesFromSummary.
Source:R/trajectoriesFromSummaryForApp.R
trajectoriesFromSummaryForApp.RdDemographic projections for cases with no change in demographic rates over time. This is the method used (so far) in the demography app. TO DO: Consider removing and replacing with call to trajectoriesFromSummary.
Usage
trajectoriesFromSummaryForApp(
numSteps,
replicates,
N0,
R_bar,
S_bar,
R_sd,
S_sd,
R_iv_mean,
R_iv_shape,
S_iv_mean,
S_iv_shape,
scn_nm,
type = "logistic",
addl_params = list(),
doSummary = F,
returnSamples = T
)Arguments
- numSteps
Number. Number of years to project.
- replicates
- N0
Number or vector of numbers. Initial population size for one or more sample populations. If NA then population growth rate is $_t=S_t*(1+cR_t)/s$.
- R_bar
Number or vector of numbers. Expected recruitment rate (calf:cow ratio) for one or more sample populations.
- S_bar
Number or vector of numbers. Expected adult female survival for one or more sample populations.
- R_sd, S_sd
standard deviation of R_bar and S_bar
- R_iv_mean, R_iv_shape, S_iv_mean, S_iv_shape
define the mean and shape of the interannual variation
- scn_nm
Scenario name
- type
"logistic" or "beta" defines how demographic rates are sampled from the given mean and standard deviation.
- addl_params
a list of additional parameters for
caribouPopGrowth- doSummary
logical. Default TRUE. If FALSE returns unprocessed outcomes from caribouPopGrowth. If TRUE returns summaries and (if returnSamples = T) sample trajectories from prepareTrajectories.
- returnSamples
logical. If FALSE returns only summaries. If TRUE returns example trajectories as well.
See also
Caribou demography functions:
bayesianScenariosWorkflow(),
bayesianTrajectoryWorkflow(),
betaNationalPriors(),
caribouPopGrowth(),
compareTrajectories(),
compositionBiasCorrection(),
convertTrajectories(),
dataFromSheets(),
demographicProjectionApp(),
demographyDefaults(),
disturbanceDefaults(),
estimateBayesianRates(),
estimateNationalRate(),
getNationalCoefficients(),
getScenarioDefaults(),
monitoringDefaults(),
nationalTrajectoryDefaults(),
plotCompareTrajectories(),
plotSurvivalSeries(),
plotTrajectories(),
popGrowthTableJohnsonECCC,
simulateObservations(),
timeDefaults(),
trajectoriesFromBayesian(),
trajectoriesFromNational(),
trajectoriesFromSummary()
Examples
outParTab <- trajectoriesFromSummaryForApp(
numSteps = 5, replicates = 2, N0 = NA, R_bar = 0.18, S_bar = 0.87,
R_sd = 0.085, S_sd = 0.16,
R_iv_mean = 0.34, S_iv_mean = 0.31,
R_iv_shape = 18, S_iv_shape = 3.3,
scn_nm = "base", addl_params = NULL, type = "logistic"
)
outParTab
#> N0 lambda lambdaE N R_t X_t S_t n_recruits
#> 1 NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000 NA
#> 2 NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000 NA
#> 3 NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000 NA
#> 4 NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000 NA
#> 5 NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000 NA
#> 6 NA 0.9337174 0.9819507 NA 0.2023911 0.10119554 0.8479124 NA
#> 7 NA 0.5642998 0.9418377 NA 0.1263247 0.06316233 0.5307748 NA
#> 8 NA 0.9809810 0.9819507 NA 0.1988048 0.09940242 0.8922857 NA
#> 9 NA 0.9663861 0.9418377 NA 0.1254951 0.06274757 0.9093280 NA
#> 10 NA 0.9808623 0.9819507 NA 0.2606638 0.13033190 0.8677649 NA
#> 11 NA 1.0609920 0.9418377 NA 0.2716518 0.13582589 0.9341150 NA
#> 12 NA 0.9921499 0.9819507 NA 0.2039116 0.10195580 0.9003536 NA
#> 13 NA 0.8460021 0.9418377 NA 0.1512410 0.07562050 0.7865247 NA
#> 14 NA 0.9387053 0.9819507 NA 0.1353284 0.06766420 0.8792140 NA
#> 15 NA 0.7731731 0.9418377 NA 0.2531829 0.12659145 0.6862941 NA
#> surviving_adFemales id time type scn
#> 1 NA 1 1 mean base
#> 2 NA 1 2 mean base
#> 3 NA 1 3 mean base
#> 4 NA 1 4 mean base
#> 5 NA 1 5 mean base
#> 6 NA 1 1 samp base
#> 7 NA 2 1 samp base
#> 8 NA 1 2 samp base
#> 9 NA 2 2 samp base
#> 10 NA 1 3 samp base
#> 11 NA 2 3 samp base
#> 12 NA 1 4 samp base
#> 13 NA 2 4 samp base
#> 14 NA 1 5 samp base
#> 15 NA 2 5 samp base