Skip to contents

Demographic projections for cases with no change in demographic rates over time. This is the method used (so far) in the demography app. TO DO: Consider removing and replacing with call to trajectoriesFromSummary.

Usage

trajectoriesFromSummaryForApp(
  numSteps,
  replicates,
  N0,
  R_bar,
  S_bar,
  R_sd,
  S_sd,
  R_iv_mean,
  R_iv_shape,
  S_iv_mean,
  S_iv_shape,
  scn_nm,
  type = "logistic",
  addl_params = list(),
  doSummary = F,
  returnSamples = T
)

Arguments

numSteps

Number. Number of years to project.

replicates
N0

Number or vector of numbers. Initial population size for one or more sample populations. If NA then population growth rate is $_t=S_t*(1+cR_t)/s$.

R_bar

Number or vector of numbers. Expected recruitment rate (calf:cow ratio) for one or more sample populations.

S_bar

Number or vector of numbers. Expected adult female survival for one or more sample populations.

R_sd, S_sd

standard deviation of R_bar and S_bar

R_iv_mean, R_iv_shape, S_iv_mean, S_iv_shape

define the mean and shape of the interannual variation

scn_nm

Scenario name

type

"logistic" or "beta" defines how demographic rates are sampled from the given mean and standard deviation.

addl_params

a list of additional parameters for caribouPopGrowth

doSummary

logical. Default TRUE. If FALSE returns unprocessed outcomes from caribouPopGrowth. If TRUE returns summaries and (if returnSamples = T) sample trajectories from prepareTrajectories.

returnSamples

logical. If FALSE returns only summaries. If TRUE returns example trajectories as well.

Value

a data.frame

Examples

 outParTab <- trajectoriesFromSummaryForApp(
   numSteps = 5, replicates = 2, N0 = NA, R_bar = 0.18, S_bar = 0.87,
   R_sd = 0.085, S_sd = 0.16,
   R_iv_mean = 0.34, S_iv_mean = 0.31,
   R_iv_shape = 18, S_iv_shape = 3.3,
   scn_nm = "base", addl_params = NULL, type = "logistic"
 )
 outParTab
#>    N0    lambda   lambdaE  N       R_t        X_t       S_t n_recruits
#> 1  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 2  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 3  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 4  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 5  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 6  NA 0.9738203 0.9486997 NA 0.2116718 0.10583589 0.8806192         NA
#> 7  NA 0.8672904 0.9118489 NA 0.1291396 0.06456982 0.8146862         NA
#> 8  NA 0.9993630 0.9486997 NA 0.1893599 0.09467996 0.9129271         NA
#> 9  NA 1.0671587 0.9118489 NA 0.2209963 0.11049813 0.9609730         NA
#> 10 NA 0.9479976 0.9486997 NA 0.1768484 0.08842420 0.8709818         NA
#> 11 NA 0.9409992 0.9118489 NA 0.2287820 0.11439100 0.8444067         NA
#> 12 NA 0.9624022 0.9486997 NA 0.1751709 0.08758546 0.8848980         NA
#> 13 NA 0.7255477 0.9118489 NA 0.1854611 0.09273056 0.6639768         NA
#> 14 NA 0.9445578 0.9486997 NA 0.2021806 0.10109030 0.8578386         NA
#> 15 NA 0.8660489 0.9118489 NA 0.1670400 0.08352000 0.7992920         NA
#>    surviving_adFemales id time type  scn
#> 1                   NA  1    1 mean base
#> 2                   NA  1    2 mean base
#> 3                   NA  1    3 mean base
#> 4                   NA  1    4 mean base
#> 5                   NA  1    5 mean base
#> 6                   NA  1    1 samp base
#> 7                   NA  2    1 samp base
#> 8                   NA  1    2 samp base
#> 9                   NA  2    2 samp base
#> 10                  NA  1    3 samp base
#> 11                  NA  2    3 samp base
#> 12                  NA  1    4 samp base
#> 13                  NA  2    4 samp base
#> 14                  NA  1    5 samp base
#> 15                  NA  2    5 samp base