Skip to contents

Demographic projections for cases with no change in demographic rates over time. This is the method used (so far) in the demography app. TO DO: Consider removing and replacing with call to trajectoriesFromSummary.

Usage

trajectoriesFromSummaryForApp(
  numSteps,
  replicates,
  N0,
  R_bar,
  S_bar,
  R_sd,
  S_sd,
  R_iv_mean,
  R_iv_shape,
  S_iv_mean,
  S_iv_shape,
  scn_nm,
  type = "logistic",
  addl_params = list(),
  doSummary = F,
  returnSamples = T
)

Arguments

numSteps

Number. Number of years to project.

replicates
N0

Number or vector of numbers. Initial population size for one or more sample populations. If NA then population growth rate is $_t=S_t*(1+cR_t)/s$.

R_bar

Number or vector of numbers. Expected recruitment rate (calf:cow ratio) for one or more sample populations.

S_bar

Number or vector of numbers. Expected adult female survival for one or more sample populations.

R_sd, S_sd

standard deviation of R_bar and S_bar

R_iv_mean, R_iv_shape, S_iv_mean, S_iv_shape

define the mean and shape of the interannual variation

scn_nm

Scenario name

type

"logistic" or "beta" defines how demographic rates are sampled from the given mean and standard deviation.

addl_params

a list of additional parameters for caribouPopGrowth

doSummary

logical. Default TRUE. If FALSE returns unprocessed outcomes from caribouPopGrowth. If TRUE returns summaries and (if returnSamples = T) sample trajectories from prepareTrajectories.

returnSamples

logical. If FALSE returns only summaries. If TRUE returns example trajectories as well.

Value

a data.frame

Examples

 outParTab <- trajectoriesFromSummaryForApp(
   numSteps = 5, replicates = 2, N0 = NA, R_bar = 0.18, S_bar = 0.87,
   R_sd = 0.085, S_sd = 0.16,
   R_iv_mean = 0.34, S_iv_mean = 0.31,
   R_iv_shape = 18, S_iv_shape = 3.3,
   scn_nm = "base", addl_params = NULL, type = "logistic"
 )
 outParTab
#>    N0    lambda   lambdaE  N       R_t        X_t       S_t n_recruits
#> 1  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 2  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 3  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 4  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 5  NA 0.9483000 0.9483000 NA 0.1800000 0.09000000 0.8700000         NA
#> 6  NA 0.9468888 0.9680227 NA 0.1617963 0.08089816 0.8760203         NA
#> 7  NA 0.8433145 0.9406454 NA 0.1159089 0.05795446 0.7971179         NA
#> 8  NA 1.0176801 0.9680227 NA 0.2283245 0.11416227 0.9134039         NA
#> 9  NA 0.8908351 0.9406454 NA 0.2078580 0.10392898 0.8069678         NA
#> 10 NA 0.9296728 0.9680227 NA 0.1123626 0.05618131 0.8802208         NA
#> 11 NA 0.8954989 0.9406454 NA 0.2074741 0.10373707 0.8113335         NA
#> 12 NA 0.9287675 0.9680227 NA 0.2006006 0.10030032 0.8441037         NA
#> 13 NA 0.7971582 0.9406454 NA 0.2035227 0.10176134 0.7235308         NA
#> 14 NA 0.9560063 0.9680227 NA 0.1866633 0.09333163 0.8743974         NA
#> 15 NA 0.9574028 0.9406454 NA 0.1301209 0.06506043 0.8989188         NA
#>    surviving_adFemales id time type  scn
#> 1                   NA  1    1 mean base
#> 2                   NA  1    2 mean base
#> 3                   NA  1    3 mean base
#> 4                   NA  1    4 mean base
#> 5                   NA  1    5 mean base
#> 6                   NA  1    1 samp base
#> 7                   NA  2    1 samp base
#> 8                   NA  1    2 samp base
#> 9                   NA  2    2 samp base
#> 10                  NA  1    3 samp base
#> 11                  NA  2    3 samp base
#> 12                  NA  1    4 samp base
#> 13                  NA  2    4 samp base
#> 14                  NA  1    5 samp base
#> 15                  NA  2    5 samp base